@@ -73,6 +73,19 @@ GOOD_WORDS = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bas
                  'whole', 'wick', 'wide', 'wife', 'win', 'wine', 'wing', 'wise', 'wish', 'woke', 'womb', 'wood', 'word', 'wore', 'work',
                  'worse', 'wreck', 'wright', 'write', 'wrong', 'wrote', 'wrought', 'year', 'yell', 'young', 'youth', 'zip']
     #Remove: pull, full, bull, real
+BAD_WORDS = ['okay','kinda','w','even','only','really','maybe','being','having','awhile','also','was',
+            'is','are','am','a','i','the','and','to','that','of','you','like','in','they','but','so',
+            'just','have','my','for','know','think','do','on','or','mean','not','be','with','because',
+            'well','what','all','if','this','out','at','get','about','them','go','when','me','she',
+            'one','then','had','as','up','would','right','lot','no','more','got','were','can','some','things',
+            'said','now','something','from','your','him','say','been','where','gonna','see','their','thing',
+            'how','here','her','much','kind','two','an','too','did','his','could','has','those','doing',
+            'who','these','our','than','into','everything','which','any','anything','three','never','by',
+            'why','five','should','off','through','will','whatever','wanna','us','every','done','guess','sure',
+            'does','four','might','ten','hum','six','once','either','eight','both','ah','o','d','myself','u',
+            'ones','seven','huh','s','nine','few','thousand','anybody','somebody','everybody','hafta','someone',
+            'yep','hey','anymore','kinda','seventy','yet','against','anyway','forty','ninety','wow','gotta',
+            'such','somewhere','may','bush','gore']
 MONOPHTHONGS = ['aa','ae','eh','ey','ih','iy','ow','uh','uw']
 
 class WTManager(BulkManager):
@@ -133,8 +146,10 @@ class Speaker(caching.base.CachingMixin,models.Model):
 
     def analyze(self,form):
         words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker')
-        words = words.filter(WordType__Label__regex = '^[^{<]').filter(Dialog__Speaker=self)
-        words = words.exclude(WordType__CVSkel__regex = '^C*VC*$')
+        words = words.filter(WordType__Label__regex = r'^[^{<]').filter(Dialog__Speaker=self)
+        #words = words.exclude(WordType__CVSkel__regex = r'^C*VC*$')
+        words = words.exclude(WordType__CVSkel__regex = r"^*'*$")
+        words = words.exclude(WordType__Label__in = BAD_WORDS)
         #words = words.filter(WordType__CVSkel='CVC')
         #words = words.filter(WordType__Label__in = GOOD_WORDS)
         #words = words.filter(WordType__StressVowel__in = MONOPHTHONGS)
